==> ideaIC-143.747.6-sources.jar: com/intellij/designer/actions/SelectSiblingsAction.java <==
/*
 * Copyright 2000-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.designer.actions;

import com.intellij.designer.designSurface.EditableArea;
import com.intellij.designer.model.RadComponent;
import com.intellij.designer.model.RadComponentVisitor;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

public class SelectSiblingsAction extends AnAction {
  private final EditableArea myArea;

  public SelectSiblingsAction(EditableArea area) {
    super("Select Siblings", "Select Siblings", null);
    myArea = area;
  }

  @Override
  public void actionPerformed(AnActionEvent e) {
    RadComponent rootComponent = myArea.getRootComponent();
    if (rootComponent != null) {
      final Set<RadComponent> parents = RadComponent.getParents(myArea.getSelection());
      final List<RadComponent> components = new ArrayList<RadComponent>();
      rootComponent.accept(new RadComponentVisitor() {
        @Override
        public void endVisit(RadComponent component) {
          if (parents.contains(component.getParent())) {
            components.add(component);
          }
        }
      }, true);
      myArea.setSelection(components);
    }
  }
}

==> ideaIC-173.3531.6-sources.jar: com/intellij/designer/actions/SelectSiblingsAction.java <==
/*
 * Copyright 2000-2013 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.designer.actions;

import com.intellij.designer.designSurface.EditableArea;
import com.intellij.designer.model.RadComponent;
import com.intellij.designer.model.RadComponentVisitor;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

public class SelectSiblingsAction extends AnAction {
  private final EditableArea myArea;

  public SelectSiblingsAction(EditableArea area) {
    super("Select Siblings", "Select Siblings", null);
    myArea = area;
  }

  @Override
  public void actionPerformed(AnActionEvent e) {
    RadComponent rootComponent = myArea.getRootComponent();
    if (rootComponent != null) {
      final Set<RadComponent> parents = RadComponent.getParents(myArea.getSelection());
      final List<RadComponent> components = new ArrayList<>();
      rootComponent.accept(new RadComponentVisitor() {
        @Override
        public void endVisit(RadComponent component) {
          if (parents.contains(component.getParent())) {
            components.add(component);
          }
        }
      }, true);
      myArea.setSelection(components);
    }
  }
}
